==> pyProbabilityDistributionFit-0.0.2.tar.gz: pyProbabilityDistributionFit-0.0.2/README.md <==
# pyProbabilityDistributionFit
Probabilty Distribution Fit

## Motivation
[Stackoverflow Question Distribution Fitting with Sum of Square Error](https://stackoverflow.com/questions/6620471/fitting-empirical-distribution-to-theoretical-ones-with-scipy-python/16651955#16651955)

[![pypi](https://img.shields.io/pypi/pyversions/pyProbabilityDistributionFit)](https://pypi.org/project/pyProbabilityDistributionFit/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyProbabilityDistributionFit.svg)](https://pypi.python.org/pypi/pyProbabilityDistributionFit/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/pyProbabilityDistributionFit)

### Authors
* [Saullo G. P. Castro](https://stackoverflow.com/users/832621/saullo-g-p-castro) [2013 Answer](https://stackoverflow.com/a/16651955/1497139)
* [Timothy Davenport](https://stackoverflow.com/users/2087463/tmthydvnprt) [2016 Answer](https://stackoverflow.com/a/37616966/1497139)
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)

==> pyProbabilityDistributionFit-0.0.3.tar.gz: pyProbabilityDistributionFit-0.0.3/README.md <==
# pyProbabilityDistributionFit
Probabilty Distribution Fit

## Motivation
[Stackoverflow Question Distribution Fitting with Sum of Square Error](https://stackoverflow.com/questions/6620471/fitting-empirical-distribution-to-theoretical-ones-with-scipy-python)

[![pypi](https://img.shields.io/pypi/pyversions/pyProbabilityDistributionFit)](https://pypi.org/project/pyProbabilityDistributionFit/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyProbabilityDistributionFit.svg)](https://pypi.python.org/pypi/pyProbabilityDistributionFit/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyProbabilityDistributionFit.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Documentation
* [Issue #1](https://github.com/WolfgangFahl/pyProbabilityDistributionFit/issues/1)
* [Wiki](http://wiki.bitplan.com/index.php/pyProbabilityDistributionFit)

### Authors
* [Saullo G. P. Castro](https://stackoverflow.com/users/832621/saullo-g-p-castro) [2013 Answer](https://stackoverflow.com/a/16651955/1497139)
* [Timothy Davenport](https://stackoverflow.com/users/2087463/tmthydvnprt) [2016 Answer](https://stackoverflow.com/a/37616966/1497139)
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl) [2022 Answer](https://stackoverflow.com/a/72283452/1497139)
